==> haskell-floatinghex-0.5-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FloatingHex
version:              0.5
visibility:           public
id:                   FloatingHex-0.5-3yz9VZfckqHYywtf5efZz
key:                  FloatingHex-0.5-3yz9VZfckqHYywtf5efZz
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  cb2fa76837e537859f16f7b6db30ec45
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/FloatingHex-0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/FloatingHex-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floatinghex
hs-libraries:         HSFloatingHex-0.5-3yz9VZfckqHYywtf5efZz
depends:              base-4.16.4.0 template-haskell-2.18.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floatinghex-0.5-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 FloatingHex
version:              0.5
visibility:           public
id:                   FloatingHex-0.5-AchJjivCpIPAS2cUp2htB
key:                  FloatingHex-0.5-AchJjivCpIPAS2cUp2htB
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  5b74cbccd5f74babbaa022de65161fdc
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/FloatingHex-0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/FloatingHex-0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/FloatingHex-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floatinghex
hs-libraries:         HSFloatingHex-0.5-AchJjivCpIPAS2cUp2htB
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
